@@ -14,6 +14,7 @@ from openpyxl import Workbook
 from openpyxl.styles import PatternFill, Font, Alignment
 from openpyxl.styles.colors import Color, WHITE
 from openpyxl.worksheet.datavalidation import DataValidation
+from openpyxl.utils import quote_sheetname
 
 from tqdm import trange
 import requests
@@ -99,10 +100,14 @@ def _setup_cover_sheet(ws, product, location, client, media_path):
     categories_list = [
         cat['name'] for cat in categories if cat['name'] not in unassignable_cat
     ]
-    categories_formula = ','.join(categories_list)
+    ws['AA1'].value = 'Categories'
+    cat_row_idx = 2
+    for cat in categories_list:
+        ws[f'AA{cat_row_idx}'].value = cat
+        cat_row_idx += 1
     categories_validation = DataValidation(
         type='list',
-        formula1=f'"{categories_formula}"',
+        formula1=f'{quote_sheetname("General Information")}!$AA$2:$AA${len(categories_list)}',
         allow_blank=False,
     )
     ws.add_data_validation(categories_validation)
@@ -278,7 +283,9 @@ def _fill_template_row(ws, row_idx, template):
         horizontal='left',
         vertical='top',
     )
-    ws.cell(row_idx, 5, value=template['type']).alignment = Alignment(
+    ws.cell(
+        row_idx, 5, value=template['type'] if 'type' in template else 'fulfillment'
+    ).alignment = Alignment(
         horizontal='left',
         vertical='top',
     )
@@ -381,8 +388,10 @@ def _dump_actions(ws, client, product_id, silent):
         formula1='"asset,tier1,tier2"',
         allow_blank=False,
     )
-    ws.add_data_validation(action_validation)
-    ws.add_data_validation(scope_validation)
+
+    if count > 0:
+        ws.add_data_validation(action_validation)
+        ws.add_data_validation(scope_validation)
 
     progress = trange(0, count, disable=silent, leave=True, bar_format=DEFAULT_BAR_FORMAT)
 
@@ -411,11 +420,12 @@ def _dump_configuration(ws, client, product_id, silent):
         formula1='"-,update,delete"',
         allow_blank=False,
     )
-    ws.add_data_validation(action_validation)
 
     if count == 0:
         return
 
+    ws.add_data_validation(action_validation)
+
     progress = trange(0, count, disable=silent, leave=True, bar_format=DEFAULT_BAR_FORMAT)
 
     for configuration in configurations:
@@ -513,8 +523,9 @@ def _dump_media(ws, client, product_id, silent, media_location, media_path):
         formula1='"image,video"',
         allow_blank=False,
     )
-    ws.add_data_validation(action_validation)
-    ws.add_data_validation(type_validation)
+    if count > 0:
+        ws.add_data_validation(action_validation)
+        ws.add_data_validation(type_validation)
 
     progress = trange(0, count, disable=silent, leave=True, bar_format=DEFAULT_BAR_FORMAT)
     for media in medias:
@@ -545,8 +556,9 @@ def _dump_external_static_links(ws, product, silent):
         formula1='"Download,Documentation"',
         allow_blank=False,
     )
-    ws.add_data_validation(action_validation)
-    ws.add_data_validation(link_type)
+    if count > 0:
+        ws.add_data_validation(action_validation)
+        ws.add_data_validation(link_type)
 
     progress = trange(0, count, disable=silent, leave=True, bar_format=DEFAULT_BAR_FORMAT)
 
@@ -616,13 +628,13 @@ def _dump_capabilities(ws, product, silent):
     ws['A3'].value = 'Pay-as-you-go dynamic items support'
     ws['B3'].value = '-'
     ws['C3'].value = (
-        ppu['dynamic'] if ppu and 'dynamic' in ppu else 'Disabled'
+        'Enabled' if ppu and 'dynamic' in ppu and ppu['dynamic'] else 'Disabled'
     )
     disabled_enabled.add(ws['C3'])
     ws['A4'].value = 'Pay-as-you-go future charges support'
     ws['B4'].value = '-'
     ws['C4'].value = (
-        ppu['future'] if ppu and 'future' in ppu else 'Disabled'
+        'Enabled' if ppu and 'future' in ppu and ppu['future'] else 'Disabled'
     )
     disabled_enabled.add(ws['C4'])
     ws['A5'].value = 'Consumption reporting for Reservation Items'
@@ -711,24 +723,26 @@ def _dump_templates(ws, client, product_id, silent):
         formula1='"fulfillment,inquire"',
         allow_blank=False,
     )
-    ws.add_data_validation(action_validation)
-    ws.add_data_validation(scope_validation)
-    ws.add_data_validation(type_validation)
 
     templates = client.products[product_id].templates.all()
     count = templates.count()
 
+    if count > 0:
+        ws.add_data_validation(action_validation)
+        ws.add_data_validation(scope_validation)
+        ws.add_data_validation(type_validation)
+
     progress = trange(0, count, disable=silent, leave=True, bar_format=DEFAULT_BAR_FORMAT)
 
     for template in templates:
         progress.set_description(f'Processing template {template["id"]}')
         progress.update(1)
-        if 'type' in template:
-            _fill_template_row(ws, row_idx, template)
-            action_validation.add(f'C{row_idx}')
-            scope_validation.add(f'D{row_idx}')
-            type_validation.add(f'E{row_idx}')
-            row_idx += 1
+
+        _fill_template_row(ws, row_idx, template)
+        action_validation.add(f'C{row_idx}')
+        scope_validation.add(f'D{row_idx}')
+        type_validation.add(f'E{row_idx}')
+        row_idx += 1
 
     progress.close()
     print()
